# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "bcsxp_bctmode"


def test_encode_order(self):
    message = self.order()
    expected = """J 123456                 S   NYME ANO                         LOC              A     B     """
    assert message == expected


def test_decode_query(self):
    result = self.decode("""I 089451821              """)
    expected = {
        "context": "query",
        "samples": [{"sample_id": "089451821", "type": "patient"}],
    }
    assert result == expected


def test_decode_result(self):
    date = datetime.datetime(2013, 11, 7, 11, 10, 34)
    worklist = self.decode(
        """
        R 089451832              11    100.89     % d.N.     0000 131107 11:10:34 S N H 460281
        R 089451832              12    111.89     % d.N.     0003 131107 11:10:34 S N H 460281
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {"code": "11", "date": date, "flags": ["0000"], "value": "100.89"},
                    {"code": "12", "date": date, "flags": ["0003"], "value": "111.89"},
                ],
                "sample_id": "089451832",
                "type": "patient",
            }
        ],
    }
    assert worklist == expected


def test_decode_qc(self):
    date = datetime.datetime(2013, 11, 12, 16, 41, 51)
    worklist = self.decode(
        """
        Q 5099 54                15    94.80      sec        0000 131112 16:41:51 N 460281
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "control_lot": "509954",
                "results": [{"code": "15", "date": date, "value": "94.80"}],
                "sample_id": "509954",
                "type": "control",
            }
        ],
    }
    assert worklist == expected
