# -*- coding: utf8 -*-

from __future__ import unicode_literals

from datetime import datetime

parser_class = "bep2000_astm"


def test_query(self):
    worklist = self.decode(
        """
    H|\\^&|||BEP2000|||||LIS||P|1|20140213111038
    Q|1|SAMPLE1|||ALL||||||||O
    L|1|F"""
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "SAMPLE1"}],
    }
    assert worklist == expected


def test_void_order(self):
    message = self.order(
        worklist=self.void_worklist,
        context={
            "query": self.parse(
                """
            H|\\^&|||BEP2000|||||||||20140213111038
            Q|1|SAMPLE1|||ALL||||||||O
            L|1|N"""
            )
        },
    )
    expected = """
    H|\\^&||||||||||||20130715141912
    P|1||SAMPLE1
    L|1|N"""
    assert message == expected


def test_order(self):
    message = self.order()
    expected = """H|\\^&||||||||||||20130715141912
        P|1||123456||NYME^ANO||20110513|F
        O|1|123456||^^^A^1:10|||20130513114242
        O|2|123456||^^^B|||20130513114242
        L|1|N"""
    assert message == expected


def test_result(self):
    worklist = self.decode(
        """
        H|\\^&|||9163500014
        P|1||20063207||Meir^Anna||19740410
        O|1|||^^^HBsAg
        R|1|^^^HBsAg^OD|0.002|O.D.|
        R|2|^^^HBsAg^Qual Result|Neg||
        R|3|^^^HBsAg^Quant Result|0.060||
        C|1|I|Coffret^46881^05 04 2018|I
        C|2|I|No Liquid|I
        C|3|I|Man ID|I
        L|1|N"""
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "20063207",
                "results": [
                    {"code": "HBsAg_OD", "value": "0.002", "dilution": ""},
                    {"code": "HBsAg_Qual Result", "value": "Neg", "dilution": ""},
                    {
                        "code": "HBsAg_Quant Result",
                        "value": "0.060",
                        "dilution": "",
                        "lots": [
                            {
                                "lot": "46881",
                                "expiration": datetime(2018, 4, 5),
                                "name": "Coffret",
                                "type": "reagent",
                            }
                        ],
                    },
                ],
            }
        ],
    }
    assert worklist == expected
