# -*- coding: utf8 -*-
from __future__ import unicode_literals

parser_class = "erytra"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&||||||||||P|1|20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F
    O|1|123456||^^^A|R||||||A||||||||||||||O
    O|2|123456||^^^B|R||||||A||||||||||||||O
    L|1|N
    """
    assert message == expected


def test_decode_query(self):
    worklist = self.decode(
        """
    H|\\^&|||WADIANA^0000711^ERY|||||||P|1|20140415175620
    Q|1|ALL||ALL||||||||I|
    L|1|N
    """
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "ALL"}],
    }
    assert worklist == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||WADIANA^0000711^ERY|||||LIS||P|1|199810151610
    P|1|3027|||PARISIS^ELisabeth||19670421|F
    O|1|42603027||^^^11145|R||||||A||||40||||||||||F
    R|1|^^^ABOERY.gru^Erytra.pln|B^B^Pos^^^^^^^Neg^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^|Gr^GrH^D^Du^Ph^C.F^E.F^c.F^e.F^K^AHG^IgG^C3d^IAC^IAP^I^II^III^IV^IP^IIP^IIIP^IVP^1^2^3^4^5^6^7^8^9^10^11^12^13^14^15^ACC^1P^2P^3P^4P^5P^6P^7P^8P^9P^10P^11P^12P^13P^14P^15P^ACP^EC^Cw^Fya^Fyb^Jka^Jkb^S^s^k^Kpa^Kpb^M^N^Lua^Lub^Lea^Leb||N||F||LAETI|||WADIANA^0000711^ERY|
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "42603027",
                "results": [
                    {"code": "ABOERY.gru_1", "value": "B"},
                    {"code": "ABOERY.gru_2", "value": "B"},
                    {"code": "ABOERY.gru_3", "value": "Pos"},
                    {"code": "ABOERY.gru_10", "value": "Neg"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    worklist = self.decode(
        """
    H|\\^&|||REPORT^000^ERY|||||||P|1|20150702091351
    P|1|CQ2100091150722|||^^^^|
    O|1|CQ9400091150722||^^^ABOERY.gru^Erytra.pln|R|20150702082713|||||||#-1^031561820011^021052000305^021152000304^718401160010196383|||||||||||REPORT^000^ERY|F|
    R|1|^^^ABOERY.gru^Erytra.pln|0^0^Pos^^^^^^^Pos^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^|Gr^GrH^D^Du^Ph^C.Fw^E.Fw^c.Fw^e.Fw^K^AHG^IgG^C3d^IAC^IAP^I^II^III^IV^IP^IIP^IIIP^IVP^1^2^3^4^5^6^7^8^9^10^11^12^13^14^15^ACC^1P^2P^3P^4P^5P^6P^7P^8P^9P^10P^11P^12P^13P^14P^15P^ACP^EC^Cw^Fya^Fyb^Jka^Jkb^S^s^k^Kpa^Kpb^M^N^Lua^Lub^Lea^Leb^P1||N||F||JNL|20150702082713|20150702084534|REPORT^000^ERY|
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "CQ9400091150722",
                "sample_id": "CQ9400091150722",
                "results": [
                    {"code": "ABOERY.gru_1", "value": "0"},
                    {"code": "ABOERY.gru_2", "value": "0"},
                    {"code": "ABOERY.gru_3", "value": "Pos"},
                    {"code": "ABOERY.gru_10", "value": "Pos"},
                ],
            }
        ],
    }
    assert worklist == expected
