# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "gem4000"


def test_result(self):
    result = self.decode(
        """
    H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0.0|||||CERNER||P|LIS2-A|20151012142358
    P|1||1234567890|LBLAKE01|BLAKE^LINDSEY|19221123|U
    C|1|P|FIELD^Billing Number^235634|G
    O|1|99999|99999||||||||||||A-VC
    C|1|P|FIELD^Priority^High|G
    C|2|P|COMMENT^What a wonderful day^20151012141516^fdyson|G
    R|1|^^^pH|7.22|||||F||123456789||20151012142357
    R|2|^^^pCO2|62|mmHg||||F
    R|6|^^^Ca++|5.00|mmol/L||||X
    C|1|I|<^Outside Reportable Range|I
    C|1|I|I^Interference Detecte|I
    R|7|^^^Hct|65|%||>||F
    L|1"""
    )
    date = datetime.datetime(2015, 10, 12, 14, 23, 57)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "99999",
                "results": [
                    {
                        "flags": [],
                        "instrument": "G4K",
                        "date": date,
                        "value": "7.22",
                        "code": "pH",
                        "operator": "123456789",
                    },
                    {
                        "flags": [],
                        "instrument": "G4K",
                        "date": date,
                        "value": "62",
                        "code": "pCO2",
                        "operator": "123456789",
                    },
                    {
                        "flags": ["<", "I"],
                        "instrument": "G4K",
                        "date": date,
                        "value": "5.00",
                        "code": "Ca++",
                        "operator": "123456789",
                    },
                    {
                        "flags": [">"],
                        "instrument": "G4K",
                        "date": date,
                        "value": "65",
                        "code": "Hct",
                        "operator": "123456789",
                    },
                    {
                        "instrument": "G4K",
                        "date": date,
                        "value": "What a wonderful day",
                        "code": "COMMENT",
                    },
                    {
                        "instrument": "G4K",
                        "date": date,
                        "value": "123456789",
                        "code": "OPE",
                    },
                    {
                        "instrument": "G4K",
                        "date": date,
                        "value": "A-VC",
                        "code": "PRELEV",
                    },
                ],
            }
        ],
    }
    assert result == expected


def test_result_gem3500(self):
    date = datetime.datetime(2023, 12, 19, 12, 57, 9)
    self.configure(gem4000_no_tube_p4=True)
    result = self.decode(
        """
    H|\\^&|||GEM 3500^7.2.5     ^16096980^^667855^2.4|||||||||20231219125843
    P|1||335317000191||TEST
    O|1||19||||||||||||A
    R|1|^^^Ca++|1.12|mmol/L||||||MB||20231219125709
    R|2|^^^BE(B)|0.5|mmol/L
    R|3|^^^HCO3-|24.6|mmol/L
    R|4|^^^Hct|39|%
    L|1
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "335317000191",
                "results": [
                    {
                        "code": "Ca++",
                        "date": date,
                        "flags": [],
                        "instrument": "",
                        "operator": "MB",
                        "value": "1.12",
                    },
                    {
                        "code": "BE(B)",
                        "date": date,
                        "flags": [],
                        "instrument": "",
                        "operator": "MB",
                        "value": "0.5",
                    },
                    {
                        "code": "HCO3-",
                        "date": date,
                        "flags": [],
                        "instrument": "",
                        "operator": "MB",
                        "value": "24.6",
                    },
                    {
                        "code": "Hct",
                        "date": date,
                        "flags": [],
                        "instrument": "",
                        "operator": "MB",
                        "value": "39",
                    },
                    {"code": "OPE", "date": date, "instrument": "", "value": "MB"},
                    {"code": "PRELEV", "date": date, "instrument": "", "value": "A"},
                ],
            }
        ],
    }
    assert result == expected


def test_query(self):
    worklist = self.decode(
        """
    H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0|||||CERNER||P|LIS2-A|20050922142358
    Q|1|^SampleNum19^^SPECIMENID||||||||||D
    L|1|N"""
    )
    expected = {
        "context": "query",
        "samples": [{"type": "patient", "sample_id": "SampleNum19"}],
    }
    assert worklist == expected


def test_seg_m(self):
    worklist = self.decode(
        """
    H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0|||||CERNER||P|LIS2-A|20050922142358<CR>
    M|1|iQM-MCA|2004^04|en
    C|1|I|213966^Persistent pH Sensor Error^Sensor Output Adjusted^pH Disabled|G
    C|2|I|213966^Interference Detected After Sample# 38. Operator John Smith^Operator Notified. Sensor Output Adjusted^Cleared|G
    L|1|N
    """
    )
    assert worklist == {"context": "result", "samples": []}


def test_order(self):
    worklist = self.encode(
        self.order_worklist,
        context={
            "query": self.parse(
                """
        H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0|||||CERNER||P|LIS2-A|20151012142358
        Q|1|^SampleNum19^^SPECIMENID||||||||||F
        L|1
        """
            )
        },
    )
    expected = """
    H|@^&||||||||||P|LIS2-A|20130715141912
    P|1|036666666|L036666666||NYME^ANO||20110513|F
    Q|1|^SampleNum19^^SPECIMENID||||||||||F
    L|1"""
    assert worklist == expected


def test_void_order_query(self):
    worklist = self.encode(
        self.void_worklist,
        context={
            "query": self.parse(
                """
        H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0|||||CERNER||P|LIS2-A|20151012142358
        Q|1|^SampleNum19^^SPECIMENID||||||||||D
        L|1"""
            )
        },
    )
    expected = """
    H|@^&||||||||||P|LIS2-A|20130715141912
    Q|1|^SampleNum19^^SPECIMENID||||||||||X
    L|1"""
    assert worklist == expected


def test_controles(self):
    worklist = self.decode(
        """
    H|@^\\|||^1.0^ICU^G4K^GEM Premier 4000^123^334^A.1.0.0|||||CERNER||P|LIS2-A|20151012142358
    P|1
    O|1||23||||||||||||P^1802^GEM CVP 1^1|||||||20151012142350|||F
    R|1|^^^pH|7.12||7.11 to 7.17|||F||123456789||20151012142350
    R|3|^^^pCO2||mmHg||||X
    C|1|I|Q^iQM Error|I
    L|1"""
    )
    date = datetime.datetime(2015, 10, 12, 14, 23, 50)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "1802",
                "control_level": "1",
                "sample_id": "1802",
                "results": [
                    {
                        "instrument": "G4K",
                        "date": date,
                        "value": "7.12",
                        "code": "pH",
                        "flags": [],
                    },
                    {
                        "instrument": "G4K",
                        "date": date,
                        "value": "",
                        "code": "pCO2",
                        "flags": ["Q"],
                    },
                ],
            }
        ],
    }
    assert worklist == expected
