# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "glims"


def test_decode_results_exemple_1(self):
    worklist = self.decode(
        """
    MSH|^~\\&|GLIMS|cyberlab_HOUL|0844|cyberlab_HOUL|20220621003710||OUL^R22|052200092606|P|2.5|||NE|AL||8859/15|FR^Francais^GLIMS
    PID|1||2100523315^^^I_APHM||Nom&&Nom^Prenom^^^^Mme^L||YYYYMMDD|F|||Adresse Line1^Adresse Line2^MARSEILLE^^13010^FRA||06XXXXXXXX^PRN^CP^^^^^^^^^06XXXXXXXX~^NET^Internet^XXXX@msn.com|||||||||||N||||||N
    PV1|1|O|^^^^^^^^^^GLIMS||||||||||||||||58646622|||||||||||||||||||||||||20220601143500|20220601235959
    ORC|SC||1220085338^GLIMS||CM||^^^20220620190000^^R||20220621003710||||0844^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS|
    OBR|1||1220085338^GLIMS|BG_SNG_HCGDDR_R^Date des dernieres regles^GLIMS^BG_SNG_HCGDDR_R^Date des dernieres regles^GLIMS|||20220620190000|||||||||||||||20220621003710||TIMONE|F||^^^20220620190000^^R|0844^MEDECINE DU TRAVAIL-TA&&MEDECINE DU TRAVAIL-TA^^^^^^ward^GLIMS
    TQ1|||||||20220620190000||R
    OBX|1|ST|BG_SNG_HCGDDR_R^Date des dernieres regles^GLIMS||15/05/22|||N|||F|||20220620190000|0556^Biochime Timone PTRR^I_APHM^0556^^I_APHM|Zscnd2^SCAN^DEMANDE2^^^^^^GLIMS||DI_RENSEIGNEMENTS_T^GLIMS|20220620221030
    ORC|SC||1220085338^GLIMS||CM||^^^20220620190000^^R||20220621003710||||0844^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS|
    OBR|2||1220085338^GLIMS|BG_HCG^HCG Totale^GLIMS|||20220620190000|||||||||||||||20220621003710||TIMONE|F||^^^20220620190000^^R|0844^MEDECINE DU TRAVAIL-TA&&MEDECINE DU TRAVAIL-TA^^^^^^ward^GLIMS
    TQ1|||||||20220620190000||R
    OBX|1|FT|BG_SNG_HCGVN_R^VN HCG^GLIMS||Presomption de grossesse si HCG > 5 UI/L. Pour les valeurs tres basses, de l'ordre de 3 a 10 UI/L, en fonction du contexte clinique et au moindre doute, un 2eme dosage devra etre effectue apres 48h.|||N|||F|||20220620190000|0556^Biochime Timone PTRR^I_APHM^0556^^I_APHM|Zscnd2^SCAN^DEMANDE2^^^^^^GLIMS||DI_RENSEIGNEMENTS_T^GLIMS|20220620221030
    SPM|1|^122008533801&GLIMS||99_PHLI_GE_3^Plasma Heparine Litium avec Gel^GLIMS||||||||0^mL&mL&GLIMS|||||20220620190000|20220620221030||Y
    ORC|SC||1220085338^GLIMS||CM||^^^20220620190000^^R||20220621003710||||0844^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS||
    OBR|3||1220085338^GLIMS|BG_HCG^HCG Totale^GLIMS|||20220620190000||0^mL&mL&GLIMS|||||20220620221030|99_PHLI_GE_3&Plasma Heparine Litium avec Gel&GLIMS|||||||20220621003710||TIMONE|F||^^^20220620190000^^R|0844^MEDECINE DU TRAVAILTA&&MEDECINE DU TRAVAIL-TA^^^^^^ward^GLIMS
    TQ1|||||||20220620190000||R
    OBX|1|FT|BG_SNG_HCGT_Q^HCG totale^GLIMS||8765 RV|UI/L^^GLIMS|0-5|A|||F|||20220620190000|0556^Biochime Timone PTRR^I_APHM^0556^^I_APHM|Code_valideur^Nom_Valideur&&Nom_Valideur^Prenom_valideur^^^^^^GLIMS |Methode: chimiluminescence^Methode: chimiluminescence^GLIMS|BS_ATELLICA_T1^GLIMS|20220621003644
    """
    )
    expected = {
        "samples": [
            {
                "type": "patient",
                "sample_id": "122008533801",
                "patient_id": "2100523315",
                "request_id": "1220085338",
                "results": [
                    {
                        "type": "FT",
                        "code": "BG_SNG_HCGT_Q",
                        "label": "HCG totale",
                        "value": "8765 RV",
                        "unit": "UI/L",
                        "flags": ["A"],
                        "date": datetime.datetime(2022, 6, 21, 0, 36, 44),
                        "operator": "Code_valideur",
                        "instrument": "BS_ATELLICA_T1",
                        "comments": ["BS_ATELLICA_T1"],
                    },
                    {
                        "type": "ST",
                        "code": "BG_SNG_HCGDDR_R",
                        "label": "Date des dernieres regles",
                        "value": "15/05/22",
                        "unit": "",
                        "flags": ["N"],
                        "date": datetime.datetime(2022, 6, 20, 22, 10, 30),
                        "operator": "Zscnd2",
                        "instrument": "DI_RENSEIGNEMENTS_T",
                        "comments": ["DI_RENSEIGNEMENTS_T"],
                    },
                ],
            }
        ],
        "context": "result",
        "sender_id": "GLIMS",
        "receiver_id": "0844",
    }
    assert worklist == expected


def test_decode_results_exemple_2(self):
    worklist = self.decode(
        """
    MSH|^~\\&|GLIMS|cyberlab_HOUL|130001225|cyberlab_HOUL|20220621083904||OUL^R22|052500073943|P|2.5|||NE|AL||8859/15|FR^Francais^GLIMS
    PID|1||2784417^^^I_APHM|| Nom&&Nom^Prenom^^^^M^L||YYYYMMDD|M|||Adresse migne1^Adresse Ligne2^GRANS^^13450^FRA||06XXXXXXXX^PRN^CP^^^^^^^^^06XXXXXXXX|||||||||||N||||||N
    PV1|1|O|9916^^^^^^^^^^GLIMS||||||||||||||||58711655|||||||||||||||||||||||||20220614121200|20220614235959
    SPM|1|^122006699401&GLIMS||99_SSEC_GE_3.5^Serum avec Gel et Activateur 3.5ml^GLIMS||||||||0^mL&mL&GLIMS|||||20220614134500|20220614134920||Y
    ORC|SC||1220066994^GLIMS||A||^^^20220614134500^^R||20220621083904|||LIMMUNO^Laboratoire d'immunologie&&Laboratoire d'immunologie^^^^^^lab^GLIMS|130001225^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS|
    OBR|1||1220066994^GLIMS|IS_CARDIOLIGG^Anti-cardiolipine G^GLIMS|||20220614134500||0^mL&mL&GLIMS|||||20220614134920|99_SSEC_GE_3.5&Serum avec Gel et Activateur 3.5ml&GLIMS|LIMMUNO^Laboratoire d'immunologie&&Laboratoire d'immunologie^^^^^^lab^GLIMS||||||20220621083904||TIMONE|P||^^^20220614134500^^R|130001225^^^^^^^^GLIMS
    TQ1|||||||20220614134500||R
    OBX|1|ST|IS_SNG_ACCARDIOG_Q^Anti-cardiolipine (IgG)^GLIMS|||U/mL^?^GLIMS|<15.00|N|||F|||20220614134500|6728^Immuno Spe APL^I_APHM^6728^^I_APHM|Code_valideur^Nom_Valideur&&Nom_Valideur^Prenom_valideur^^^^^^GLIMS |Methode: ELISA^Methode:ELISA^GLIMS|ONELINK_MANUEL^GLIMS|20220621083848
    ORC|SC||1220066994^GLIMS||A||^^^20220614134500^^R||20220621083904|||LIMMUNO^Laboratoire d'immunologie&&Laboratoire d'immunologie^^^^^^lab^GLIMS|130001225^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS|
    OBR|2||1220066994^GLIMS|IS_CARDIOLIGM^Anti-cardiolipine M^GLIMS|||20220614134500||0^mL&mL&GLIMS|||||20220614134920|99_SSEC_GE_3.5&Serum avec Gel et Activateur 3.5ml&GLIMS|LIMMUNO^Laboratoire d'immunologie&&Laboratoire d'immunologie^^^^^^lab^GLIMS||||||20220621083904||TIMONE|P||^^^20220614134500^^R|130001225^^^^^^^^GLIMS
    TQ1|||||||20220614134500||R
    OBX|1|ST|IS_SNG_ACCARDIOM_Q^Anti-cardiolipine (IgM)^GLIMS|||U/mL^?^GLIMS|<15.00|N|||F|||20220614134500|6728^Immuno Spe APL^I_APHM^6728^^I_APHM|Code_valideur^Nom_Valideur&&Nom_Valideur^Prenom_valideur^^^^^^GLIMS|Methode: ELISA^Methode: ELISA^GLIMS|ONELINK_MANUEL^GLIMS|20220621083848
    """
    )
    expected = {
        "samples": [
            {
                "type": "patient",
                "sample_id": "122006699401",
                "patient_id": "2784417",
                "request_id": "1220066994",
                "results": [
                    {
                        "type": "ST",
                        "code": "IS_SNG_ACCARDIOG_Q",
                        "label": "Anti-cardiolipine (IgG)",
                        "value": "",
                        "unit": "U/mL",
                        "flags": ["N"],
                        "date": datetime.datetime(2022, 6, 21, 8, 38, 48),
                        "operator": "Code_valideur",
                        "instrument": "ONELINK_MANUEL",
                        "comments": ["ONELINK_MANUEL"],
                    }
                ],
            }
        ],
        "context": "result",
        "sender_id": "GLIMS",
        "receiver_id": "130001225",
    }
    assert worklist == expected


def test_decode_results_exemple_3(self):
    worklist = self.decode(
        """
        MSH|^~\\&|GLIMS|TestT_Onelink_Synchro|OneLink|TestT_Onelink_Synchro|20230418111906||OUL^R22|000000079376|P|2.5|||NE|AL
PID|1||2100451771^^^I_APHM||TEST-RADIS&&TEST-RADIS^TEST-BLANC^^^^M.^L||19800110|M|||place castellane.^15^MARSEILLE^^13005^FRA|||||||||||||N||||||N
PD1||||10003330783^KAROUBY&&KAROUBY^PATRICK^^^^DR^hcpr^GLIMS
SPM|1|^123000014401&GLIMS||99_PHLI_GE_3^Plasma Hparine Litium avec Gel^GLIMS||||||||0^mL&mL&GLIMS|||||20230417175600|20230417175657||N|^TC
OBR|1||1230000144^GLIMS|BG_SNG_PROT_Q^Protines^GLIMS|||20230417175600||0^mL&mL&GLIMS|||||20230417175657|99_PHLI_GE_3&Plasma Hparine Litium avec Gel&GLIMS|1006^HOSPIT.NEUROLOGIE NEUROPSYCHO.-TA&&HOSPIT.NEUROLOGIE NEUROPSYCHO.-TA^^^^^^ward^GLIMS||||||20230418111906||TIMONE|P||^^^20230417175600^^R
ORC|SC||1230000144^GLIMS||A||^^^20230417175600^^R||20230418111906|||1006^HOSPIT.NEUROLOGIE NEUROPSYCHO.-TA&&HOSPIT.NEUROLOGIE NEUROPSYCHO.-TA^^^^^^ward^GLIMS|^^^^^^^^^^GLIMS||||TIMONE^Saisie Timone^GLIMS||10001987543^LACARELLE&&LACARELLE^BRUNO^^^^^hcpr^GLIMS
OBX|1|ST|PROT_SNG^Protines^ONELINK^BG_SNG_PROT_Q^Protines^GLIMS||non ralisable : tube cass|g/L^^GLIMS|57.0-82.0|N|||P|||20230417175600||E015686^Nadeau^Guillaume^^^^^^GLIMS|Mthode:  Biuret^Mthode:  Biuret^GLIMS|ONELINK_MANUEL^GLIMS|20230417175840
"""
    )
    expected = {
        "receiver_id": "OneLink",
        "sender_id": "GLIMS",
        "context": "result",
        "samples": [
            {
                "sample_id": "123000014401",
                "patient_id": "2100451771",
                "type": "patient",
                "results": [
                    {
                        "code": "PROT_SNG",
                        "date": datetime.datetime(2023, 4, 17, 17, 58, 40),
                        "value": "non ralisable : tube cass",
                        "label": "Protines",
                        "instrument": "ONELINK_MANUEL",
                        "flags": ["N"],
                        "operator": "E015686",
                        "type": "ST",
                        "unit": "g/L",
                        "comments": ["ONELINK_MANUEL"],
                    }
                ],
                "request_id": "1230000144",
            }
        ],
    }
    assert worklist == expected
