# -*- coding: utf8 -*-
from __future__ import unicode_literals

import copy
import datetime

parser_class = "masslynx"


def test_decode_result1(self):
    date = datetime.datetime(2017, 10, 5, 14, 50, 8)
    worklist = self.decode(
        """
    MSH|^~\\&|LIMS Interface|LIMS Interface|LIMS|LIMS|20171005145008||OUL^R22|23_20171005145009|P|2.5
    PID|||4473802788||Walsh
    OBR||48456||^Metanephrines||||||||||||||||Analyte
    ORC|AF
    OBX|1|NM|Metanephrine|NA||253.9320098494||||||F
    OBX|2|NM|Normetanephrine|NA||496.4919804870||||||F
    OBX|3|NM|d3 Met IS|NA||1.2201699331||||||F
    OBX|4|NM|d3 Normet IS|NA||1.1809933981||||||F
    OBX|5|NM|3MT|NA||179.3891481142||||||F
    OBX|6|NM|D4 3MT|NA||1.2904085149||||||F
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "48456",
                "results": [
                    {"code": "Metanephrine", "date": date, "value": "253.9320098494"},
                    {
                        "code": "Normetanephrine",
                        "date": date,
                        "value": "496.4919804870",
                    },
                    {"code": "d3 Met IS", "date": date, "value": "1.2201699331"},
                    {"code": "d3 Normet IS", "date": date, "value": "1.1809933981"},
                    {"code": "3MT", "date": date, "value": "179.3891481142"},
                    {"code": "D4 3MT", "date": date, "value": "1.2904085149"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_result2(self):
    self.configure(masslynx_version32=True)
    date = datetime.datetime(2023, 1, 25, 13, 43, 57)
    worklist = self.decode(
        """
        MSH|^~\\&|LIMS Interface|LIMS Interface|LIMS|LIMS|20230125134357||ORL^O22|3_20230125134358|P|2.5
        MSA|AA|4_20230125134358||||NA
        PID
        OBR||13532396||^BETALACTAMINES||||||||||||||||Analyte
        ORC|RE
        OBX|1|NM|^Amoxicilline|NA|||||||F
        OBX|2|NM|^Meropenem|NA|||||||F
        OBX|3|NM|^Oxacilline|NA|9.9580095237||||||F
    """
    )
    assert worklist.samples[0].sample_id == "13532396"
    expected = {
        "samples": [
            {
                "sample_id": "13532396",
                "type": "patient",
                "results": [
                    {"code": "Amoxicilline", "value": "", "date": date},
                    {"code": "Meropenem", "value": "", "date": date},
                    {"code": "Oxacilline", "value": "9.9580095237", "date": date},
                ],
            }
        ],
        "context": "result",
    }
    assert worklist == expected


def test_decode_results_multiple_samples(self):
    date = datetime.datetime(2017, 10, 5, 15, 29, 42)
    worklist = self.decode(
        """
    MSH|^~\\&|LIMS Interface|LIMS Interface|LIMS|LIMS|20171005152942||OUL^R22|2_20171005152942|P|2.5
    PID|||4471265026||Pritchard
    OBR||34120||^Metanephrines|||||||||2|||||Metas_5_10_17.qld||Analyte|XEVO-TQS#WAB1190
    ORC|AF
    OBX|1|NM|Metanephrine|NA||11.6720014006|||0|||F
    OBX|2|NM|Normetanephrine|NA|||||1|||F
    OBX|3|NM|d3 Met IS|NA||2.7592271031|||0|||F
    OBX|4|NM|d3 Normet IS|NA||1.9789708856|||0|||F
    OBX|5|NM|3MT|NA||44.8646125494|||0|||F
    OBX|6|NM|D4 3MT|NA||3.1446496390|||0|||F
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "34120",
                "results": [
                    {
                        "code": "Metanephrine",
                        "date": date,
                        "flags": ["0"],
                        "value": "11.6720014006",
                    },
                    {
                        "code": "Normetanephrine",
                        "date": date,
                        "flags": ["1"],
                        "value": "",
                    },
                    {
                        "code": "d3 Met IS",
                        "date": date,
                        "flags": ["0"],
                        "value": "2.7592271031",
                    },
                    {
                        "code": "d3 Normet IS",
                        "date": date,
                        "flags": ["0"],
                        "value": "1.9789708856",
                    },
                    {
                        "code": "3MT",
                        "date": date,
                        "flags": ["0"],
                        "value": "44.8646125494",
                    },
                    {
                        "code": "D4 3MT",
                        "date": date,
                        "flags": ["0"],
                        "value": "3.1446496390",
                    },
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2020, 10, 27, 17, 4, 58)
    worklist = self.decode(
        """
    MSH|^~\\&|LIMS Interface|LIMS Interface|LIMS|LIMS|20201029154414||OUL^R22|3_20201029154414|P|2.5
    PID
    OBR||100 eau||CATEP|||27-Oct-20|17:04:58|||1:13||||||||20202710_CatMetPlasma_016|202710 serie Alain et romain test 2 export.qld|QC|XEVO-TQXS#WBA1001
    ORC|RE
    OBX|1|NM|3-Methoxythyramine|NA||112.3768942155|||||F
    OBX|2|NM|Epinephrine|NA||126.2480942379|||||F
    OBX|3|NM|Metanephrine|NA||127.9861792215|||||F
    OBX|4|NM|Norepinephrine|NA||136.2139798600|||||F
    OBX|5|NM|Normetanephrine|NA||140.2667135526|||||F
    OBX|6|NM|Dopamine|NA||110.9314067959|||||F
    OBX|7|NM|3-Methoxythyramine-D3|NA||1.0715576054|||||F
    OBX|8|NM|Metanephrine-D3|NA||1.0760360615|||||F
    OBX|9|NM|Norepinephrine-D6|NA||0.8636066597|||||F
    OBX|10|NM|Normetanephrine-D3|NA||1.0399104307|||||F
    OBX|11|NM|Epinephrine-D6|NA||1.1433481013|||||F
    OBX|12|NM|Dopamine-D4|NA||1.1076212290|||||F
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "results": [
                    {
                        "code": "3-Methoxythyramine",
                        "date": date,
                        "value": "112.3768942155",
                    },
                    {"code": "Epinephrine", "date": date, "value": "126.2480942379"},
                    {"code": "Metanephrine", "date": date, "value": "127.9861792215"},
                    {"code": "Norepinephrine", "date": date, "value": "136.2139798600"},
                    {
                        "code": "Normetanephrine",
                        "date": date,
                        "value": "140.2667135526",
                    },
                    {"code": "Dopamine", "date": date, "value": "110.9314067959"},
                    {
                        "code": "3-Methoxythyramine-D3",
                        "date": date,
                        "value": "1.0715576054",
                    },
                    {"code": "Metanephrine-D3", "date": date, "value": "1.0760360615"},
                    {
                        "code": "Norepinephrine-D6",
                        "date": date,
                        "value": "0.8636066597",
                    },
                    {
                        "code": "Normetanephrine-D3",
                        "date": date,
                        "value": "1.0399104307",
                    },
                    {"code": "Epinephrine-D6", "date": date, "value": "1.1433481013"},
                    {"code": "Dopamine-D4", "date": date, "value": "1.1076212290"},
                ],
                "sample_id": "100 eau",
                "control_lot": "100 eau",
                "type": "control",
            }
        ],
    }
    assert worklist == expected


def test_encode_order(self):
    message = self.order(context={"control_id": "1521651964637"})
    expected = """
    MSH|^~\\&|||||20130715141912||OML^O21|1521651964637|P|2.5
    PID|||036666666||NYME^ANO|NJF|20110513|F
    ORC|NW
    OBR||123456||A|||03-Jun-13|11:03:42|||||||||||||Serum
    ORC|NW
    OBR||123456||B|||03-Jun-13|11:03:42|201302131516||||||||||||Serum
    """
    assert message == expected

    self.configure(masslynx_version32=True)
    expected2 = """
    MSH|^~\\&|||||20130715141912||OML^O21|1521651964637|P|2.5
    PID|||036666666||NYME^ANO|NJF|20110513|F
    ORC|NW
    OBR||123456||A|||20130603110342|||||||||||||Serum
    ORC|NW
    OBR||123456||B|||20130603110342||201302131516|||||||||||Serum
    MSH|^~\\&|||||20130715141912||OML^O21|1521651964638|P|2.5
    PID|||036666666||NYME^ANO|NJF|20110513|F
    ORC|NW
    OBR||79123||A|||20130603110342|||||||||||||plasma
    ORC|NW
    OBR||79123||B|||20130603110342||201302131516|||||||||||plasma
    """

    worklist = copy.deepcopy(self.order_worklist)
    sample2 = copy.deepcopy(worklist.samples[0])
    sample2.specimen = "plasma"
    sample2.sample_id = "79123"
    worklist.samples.append(sample2)
    message2 = self.order(worklist=worklist, context={"control_id": "1521651964637"})
    assert message2 == expected2
