# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "qwalys"


def test_encode_order(self):
    message = self.order()
    expected = """
    H|\\^&|||MCA^MCA|||||QWALYS^QWALYS||||20130715141912
    P|1|123456|20130513036666666||NYME^ANO|NJF|20110513|F|||||PRESCRIBER||||||||||20130513114242
    O|1||123456|^^^A|S||||||N
    O|2||123456|^^^B|S||||||N
    O|3||123456|^^^C|S||||||C
    L|1|N
    """
    assert message == expected


def test_decode_result(self):
    worklist = self.decode(
        """
    H|\\^&|||Labo ANAVO|Qwalys Data Software 1.2.0.0||||||||20140115143744
    P|1|41320500|q40115413205||BARADJI^Sp||20140114|M
    O|1||41320500|^^^GRPHBB||||||||||||||||6830031564203029||20140115132744
    R|1|^^^W^25^Anti A^GRPHBB^1|^^^^^^Neg^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|2|^^^W^26^Anti B^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|3|^^^W^27^Anti AB^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^2015033
    R|4|^^^W^28^Anti D1^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|5|^^^W^29^Anti C^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|6|^^^W^30^Anti c^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|7|^^^W^31^Anti E^GRPHBB^1|^^^^^^Neg^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|8|^^^W^32^Anti e^GRPHBB^1|^^^^^^4+^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|9|^^^W^33^Anti K^GRPHBB^1|^^^^^^Neg^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|10|^^^W^34^RH Ctrl^GRPHBB^1|^^^^^^Neg^^^^^^^^^^|M||||R||bouteill?|20140115132747
    C|1|WP
    C|2|R1^BromeLine^106490640737^649^20140630
    C|3|R2^MagneLys^115420354034^542^20150331
    R|11|^^^G0^99^^GRPHBB^1|^^^^^^B
    R|12|^^^G1^99^^GRPHBB^1|^^^^^^Pos
    R|13|^^^G2^99^^GRPHBB^1|^^^^^^CcDee
    L|1|N
    """
    )
    date = datetime.datetime(2014, 1, 15, 13, 27, 47)
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "41320500",
                "results": [
                    {
                        "date": date,
                        "value": "Neg",
                        "code": "Anti A",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti B",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti AB",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti D1",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti C",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti c",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "Neg",
                        "code": "Anti E",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "4+",
                        "code": "Anti e",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "Neg",
                        "code": "Anti K",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {
                        "date": date,
                        "value": "Neg",
                        "code": "RH Ctrl",
                        "operator": "bouteill?",
                        "flags": ["R"],
                    },
                    {"date": None, "value": "B", "code": "G0"},
                    {"date": None, "value": "BPos", "code": "G0G1"},
                    {"date": None, "value": "Pos", "code": "G1"},
                    {"date": None, "value": "CcDee", "code": "G2"},
                ],
            }
        ],
    }
    assert worklist == expected


def test_decode_control(self):
    date = datetime.datetime(2015, 6, 25, 9, 33, 43)
    worklist = self.decode(
        """
    H|\\^&|||Diagast Laboratory|Qwalys Data Software1.3.0.0||||||||20150625095245||
    P|1|4444HCQI|||4444HCQI^4444HCQI||20120614|U||^|||^|||||||||||||||||||^||||
    O|1||4444HCQI|^^^GRPH1||||||||||||||||6830061670013579||20150625093341||||||||||
    R|1|^^^W^37^AntiA^GRPH1^1|^^^^^^4+^^^^^^^^^^|M||||R||BOIZEAU|20150625093343|||
    C|1|WP^D1||
    C|2|R1^BromeLine^106740953204^674^20150930||
    C|3|R2^MagneLys^115760764133^576^20160731||
    R|2|^^^W^38^AntiB^GRPH1^1|^^^^^^Neg^^^^^^^^^^|M||||R||BOIZEAU|20150625093343|||
    C|1|WP^D2||
    C|2|R1^BromeLine^106740953204^674^20150930||
    C|3|R2^MagneLys^115760764133^576^20160731||
    R|3|^^^W^39^AntiAB^GRPH1^1|^^^^^^4+^^^^^^^^^^|M||||R||BOIZEAU|20150625093343|||
    C|1|WP^D3||
    C|2|R1^BromeLine^106740953204^674^20150930||
    C|3|R2^MagneLys^115760764133^576^20160731||
    R|4|^^^W^40^AntiD1^GRPH1^1|^^^^^^4+^^^^^^^^^^|M||||R||BOIZEAU|20150625093343|||
    C|1|WP^D4||
    C|2|R1^BromeLine^106740953204^674^20150930||
    C|3|R2^MagneLys^115760764133^576^20160731||
    L|1|N
    """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "control",
                "control_lot": "4444HCQI",
                "sample_id": "4444HCQI",
                "results": [
                    {"code": "AntiA", "value": "4+", "date": date, "flags": ["R"]},
                    {"code": "AntiB", "value": "Neg", "date": date, "flags": ["R"]},
                    {"code": "AntiAB", "value": "4+", "date": date, "flags": ["R"]},
                    {"code": "AntiD1", "value": "4+", "date": date, "flags": ["R"]},
                ],
            }
        ],
    }
    assert worklist == expected
