# -*- coding: utf8 -*-
from __future__ import unicode_literals

import datetime

parser_class = "spa_plus"


def test_encode_order(self):
    self.configure(
        spa_plus_sender_code="HOST",
        spa_plus_sender_name="P_1",
        spa_plus_receiver_code="Prestige24i",
        spa_plus_receiver_name="SYSTEM1",
    )
    message = self.order()
    expected = """
    H|\\^&|||HOST^P_1|||||Prestige24i^SYSTEM1||P|1|20130715141912
    P|1|036666666|||NYME^ANO|NJF|20110513|F|||||PRESCRIBER^Prescriber|||1.70|58||MEDOC1;MEDOC2||Commentaire patient no1||||^^SER
    O|1|123456||^^^A^^^1:10\\^^^B|R||20130603110342||||N||||Serum|PRESCRIBER^Prescriber^^SER
    O|2|123456||^^^C|R||20130603110342||||C||||Serum|PRESCRIBER^Prescriber^^SER
    L|1|N
    """
    assert message == expected


def test_decode_result(self):
    worklist = self.decode(
        """
        H|\\^&|||WST^SYSTEM1|||||LIS^P_1||P|1|20141105123203
        P|1|002000481558|||FERGUSON^Jane||19720422|F|||||||||||||||||
        O|1|0044222280|^1^91|^^^33^ALB C^2|R||20140902124100||||||||CSF||||||||||F|||||||pa
        R|1|^^^33^ALB C^2|186.7|mg/L||N||F||pa||20140903111200|SPAp|||331070
        O|2|0044222280|^1^91|^^^30^IgG C^0|R||20140902124100||||||||CSF||||||||||F|||||||pa
        R|1|^^^30^IgG C^0|19.42|mg/L||N||F||pa||20140903111200|SPAp|||341002
        L|1|N
        """
    )
    expected = {
        "context": "result",
        "samples": [
            {
                "type": "patient",
                "sample_id": "0044222280",
                "specimen": "CSF",
                "results": [
                    {
                        "code": "33",
                        "value": "186.7",
                        "date": datetime.datetime(2014, 9, 3, 11, 12),
                        "flags": ["N"],
                        "dilution": "",
                        "instrument": "SPAp",
                        "operator": "pa",
                        "comments": [],
                        "unit": "mg/L",
                        "lots": [{"lot": "331070", "type": "reagent"}],
                    },
                    {
                        "code": "30",
                        "value": "19.42",
                        "date": datetime.datetime(2014, 9, 3, 11, 12),
                        "flags": ["N"],
                        "dilution": "",
                        "instrument": "SPAp",
                        "operator": "pa",
                        "comments": [],
                        "unit": "mg/L",
                        "lots": [{"lot": "341002", "type": "reagent"}],
                    },
                ],
            }
        ],
    }
    assert worklist == expected
